<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Ws_model extends CI_Model {
	
	function __construct() {
		parent::__construct();
	}
	
	public function get_time_zone($user_id) {
		$this->db->select('time_zone');
		$this->db->from('users_time_zone');
		$this->db->where('user_id',$user_id);
		$query= $this->db->get();
		return $query->row();
	}
	
	public function get_countries() {
		$query = $this->db->get('countries');
		return $query->result();
	}
	
	function get_user_events($user_id, $limit, $offset){
		$this->db->where('user_id', $user_id);
		$this->db->limit($limit, $offset);
		$this->db->order_by('created_on', 'DESC');
		$query = $this->db->get('videos'); 
		return $query->result();
	}
	
	function count_user_events($user_id){
		$this->db->where('user_id', $user_id); 
		$this->db->from('videos');		
		return $this->db->count_all_results();
	}
	 
	function get_user_frames($user_id, $limit, $offset){
		$this->db->select('fr.*, v.kaltura_video_id, v.title as event_title, v.description as event_description, u.first_name, u.last_name');
		$this->db->from('ads_frame fr');
		$this->db->join('videos v', 'v.id = fr.video_id');
		$this->db->join('users u', 'u.id=v.user_id', 'left');
		$this->db->where('fr.user_id', $user_id);
		$this->db->limit($limit, $offset);
		$this->db->order_by('fr.created_on', 'DESC');
		$query = $this->db->get();
		return $query->result();
	}
	
	
	function get_frame_details($frame_id){
		$this->db->select('fr.*, v.kaltura_video_id, v.title as event_title, v.description as event_description, u.first_name, u.last_name');
		$this->db->from('ads_frame fr');
		$this->db->join('videos v', 'v.id = fr.video_id');
		$this->db->join('users u', 'u.id=v.user_id', 'left');
		$this->db->where('fr.id', $frame_id);
		$query = $this->db->get();
		return $query->row();
	}
		
	function count_user_frames($user_id){
		$this->db->select('fr.*, u.first_name, u.last_name');
		$this->db->from('ads_frame fr');
		$this->db->join('videos v', 'v.id = fr.video_id');
		$this->db->join('users u', 'u.id=v.user_id', 'left');
		$this->db->where('fr.user_id', $user_id); 
		$query = $this->db->get();
		return $query->result();
	}
	
	function get_user_favourites($user_id){
		$this->db->select('v.*, u.first_name, u.last_name, fv.id as favourite_id');
		$this->db->from('favourite_video fv');
		$this->db->join('videos v', 'v.id = fv.video_id');
		$this->db->join('users u', 'u.id=v.user_id', 'left');
		$this->db->where('v.active', 1);
		$this->db->where('fv.user_id', $user_id);
		$query = $this->db->get();
		return $query->result();
	}
	
	function get_user_subscribed_event($user_id){
		$this->db->select('v.*, u.first_name, u.last_name');
		$this->db->from('subscribe_video sv');
		$this->db->join('videos v', 'v.id = sv.video_id');
		$this->db->join('users u', 'u.id=v.user_id', 'left');
		$this->db->where('v.active', 1);
		$this->db->where('sv.user_id', $user_id);
		$query = $this->db->get();
		return $query->result();
	}
	
	
	/*  public function get_tag_streams($user_id, $limit, $offset) {
		$this->db->select('v.*, u.first_name, u.last_name, u.profile_image,ts.id as tag_id, ts.product_id, ts.created_on, ts.action_type');
		$this->db->from('tag_streams ts');
		$this->db->join('videos v', 'v.id=ts.event_id', 'left');
		$this->db->join('users u', 'u.id=ts.user_id');
		$this->db->join('friend_requests fr', 'fr.user_to=ts.user_id');
		$this->db->where('fr.user_from', $user_id);
		$this->db->where('fr.request', 1);
		$this->db->where('ts.action_type',"add");
		$this->db->order_by('ts.created_on', 'desc');
		$this->db->limit($limit, $offset);
		$query = $this->db->get();
		return $query->result();
	}  */
	
	public function get_tag_streams($userList, $limit, $offset) {
		$this->db->select('u.first_name, u.last_name, u.profile_image,ts.id as tag_id,ts.event_id, ts.product_id,ts.user_id, ts.created_on, ts.action_type');
		$this->db->from('tag_streams ts');
		//$this->db->join('videos v', 'v.id=ts.event_id', 'left');
		$this->db->join('users u', 'u.id=ts.user_id');
		$this->db->where_in('ts.user_id',$userList);
		$this->db->where('ts.action_type',"add");
		//$this->db->join('friend_requests fr', 'fr.user_to=ts.user_id');
		//$this->db->where('fr.user_from', $user_id);
		//$this->db->where('fr.request', 1);
		//$this->db->where('ts.action_type',"add");
		//$this->db->where_in('ts.action_type',"add");
		$this->db->order_by('ts.created_on', 'desc');
		$this->db->limit($limit, $offset);
		$query = $this->db->get();
		return $query->result();
	} 
	
	public function get_freinds($user_id){
		$this->db->where('user_from',$user_id);
		$this->db->where('request',1);
		$query= $this->db->get('friend_requests');
		return $query->result();
	}
	public function get_frame_info($frame_id){
		$this->db->where('id',$frame_id);
		$query= $this->db->get('ads_frame');
		return $query->row();
	}
	
	public function get_video_info($video_id){
		$this->db->where('id',$video_id);
		$query= $this->db->get('videos');
		//echo $this->db->last_query();
		return $query->row();
	}
	
	public function get_total_tag_streams($user_id) {
		$SQL= "SELECT id FROM (`friend_requests`) WHERE `user_from`=$user_id OR `user_to`= $user_id";
		$query = $this->db->query($SQL);
		return $query->result();
	}
	// End
	public function get_user_products($user_id){
		$this->db->select('p.*, pi.file_name');
		$this->db->from('products p');
		$this->db->join('product_images pi', 'pi.id=p.profile_image', 'left');
		$this->db->where('p.user_id', $user_id);
		$this->db->where('p.active',1);
		$query = $this->db->get();
		return $query->result();
	}
	
	public function get_search_record($search) {
		$this->db->select('v.*, u.first_name, u.last_name, u.profile_image');
		$this->db->from('users u');
		$this->db->join('videos v', 'v.user_id=u.id', 'left'); 
		$array = array('v.title' => $search, 'v.description' => $search, 'u.first_name' => $search);
		$this->db->or_like($array); 
		$query = $this->db->get();
		return $query->result();
	}
	
	public function get_timelines($user_id) {
		$this->db->select('v.*, v.id as event_id, v.created_on as event_date, fr.*, fr.id as frame_id, fr.created_on as frame_date'); 
		$this->db->from('videos v'); 
		$this->db->join('ads_frame fr', 'fr.video_id = v.id', 'left'); 
		$this->db->where('v.user_id', $user_id); 
		$query = $this->db->get();
		return $query->result();
	}
	
	public function check_subscribe($user_id, $video_id){
		$this->db->where('user_id', $user_id);
		$this->db->where('video_id', $video_id);
		$query = $this->db->get('subscribe_video');
		if($query->num_rows() == 1){
			return TRUE;
		} else {
			return FALSE;
		}
	}
	
	public function insert($table, $data){
		$this->db->insert($table, $data);
		return $this->db->insert_id();;
	}
	
	public function insert_tag_stream($streams_data) {
		$this->db->insert('tag_streams', $streams_data);
	}
	
	public function get_all_like_count($video_id){
		$this->db->select('count(id) as num');
		$this->db->where('video_id', $video_id);
		$query = $this->db->get('videos_likes');
		return $query->row()->num;
	}
	
	public function remove_video_like($user_id, $video_id) {
		$this->db->where('user_id', $user_id);
		$this->db->where('video_id', $video_id);
		$this->db->delete('videos_likes'); 
	}
	
	function insert_friends($requestData){
		$this->db->insert('friend_requests', $requestData);
		return $this->db->insert_id();
	}
	
	function check_request($user_id, $to_user_id){
		$this->db->select('user_from, user_to, request');
		$this->db->where("( user_from='".$user_id."' and user_to='".$to_user_id."')");
		$this->db->where("request",1);
		//$this->db->or_where("( user_from='".$to_user_id."' and user_to='".$user_id."')");
		$query = $this->db->get('friend_requests'); 
		return $query->row();
	}
	
	function check_is_blocked($user_id, $to_user_id){
		$this->db->select('user_from, user_to, request');
		$this->db->where("( user_from='".$user_id."' and user_to='".$to_user_id."')");
		$this->db->or_where("( user_from='".$to_user_id."' and user_to='".$user_id."')");
		$this->db->where("request",0);
		$this->db->where("is_blocked",1);
		$query = $this->db->get('friend_requests'); 
		return $query->row();
	}
	function check_other_blocked($user_id, $to_user_id){
		$this->db->select('user_from, user_to, request');
		$this->db->where("( user_from='".$to_user_id."' and user_to='".$user_id."')");
		$this->db->where("request",0);
		$query = $this->db->get('friend_requests'); 
		return $query->row();
	}
	
	function get_followers($user_id, $limit, $offset)
	{
		$this->db->select('u.*, f.user_from');
		$this->db->from('friend_requests f');
		$this->db->join('users u', 'u.id=f.user_from');
		$this->db->where('f.user_to', $user_id);
		$this->db->where('u.active', 1);
		$this->db->where('f.request', 1);
		$this->db->limit($limit, $offset);
		$query = $this->db->get(); 
		return $query->result();
	}
	
	function get_following($user_id, $limit, $offset)
	{
		$this->db->select('u.*, f.user_to');
		$this->db->from('friend_requests f');
		$this->db->join('users u', 'u.id=f.user_to');
		$this->db->where('f.user_from', $user_id);
		$this->db->where('u.active', 1);
		$this->db->where('f.request', 1);
		$this->db->limit($limit, $offset);
		$query = $this->db->get(); 
		return $query->result();
	}
	
	function delete_followers($user_id, $user_from) {
		$this->db->where('user_to', $user_id);
		$this->db->where('user_from', $user_from);
		$this->db->delete('friend_requests');
	}
	
	function delete_following($user_id, $user_to) {
		$this->db->where('user_from', $user_id);
		$this->db->where('user_to', $user_to);
		$this->db->delete('friend_requests');
	}

       function delete_followers_notification($user_id, $user_from) {
		$this->db->where('to_user_id', $user_id);
		$this->db->where('from_user_id', $user_from);
		$this->db->delete('notifications');
	}
	
	function delete_following_notification($user_id, $user_to) {
		$this->db->where('from_user_id', $user_id);
		$this->db->where('to_user_id', $user_to);
		$this->db->delete('notifications');
	}
	
	
	function get_search_user($user_id, $keyword)
	{
		$this->db->select('u.*');
		$this->db->from('users u');
		//$this->db->join('friend_requests f', 'u.id=f.user_from', 'left');
		//$this->db->where('f.user_from', null);
		//$this->db->where_not_in('u.id', $user_id);
		$this->db->where('u.active', 1);
		$this->db->like('u.first_name', $keyword);
		$this->db->or_like('u.username', $keyword);
		$this->db->or_like('u.email', $keyword);
		$query = $this->db->get();
		//echo $this->db->last_query();
		return $query->result();
	}

	function count_following($user_id)
	{
		$this->db->where('user_from', $user_id);
		$this->db->where('request', 1);
		return $this->db->count_all_results('friend_requests');
	}
	
	function count_followers($user_id)
	{
		$this->db->where('user_to', $user_id);
		$this->db->where('request', 1);
		return $this->db->count_all_results('friend_requests');
	}
	
	function insert_tagged_user($taggedUserData)
	{
		$this->db->insert('tagged_users', $taggedUserData);
		return $this->db->insert_id();
	}
	
	public function get_tagged_users($user_id, $limit, $offset) {
		$this->db->select('v.*, u.first_name, u.last_name, u.profile_image, tu.created_at,tu.user_id as tuuserId,tu.type, f.product_id');
		$this->db->from('tagged_users tu');
		$this->db->join('videos v', 'v.id=tu.video_id', 'left');
		$this->db->join('ads_frame f', 'f.id=tu.frame_id', 'left');
		$this->db->join('users u', 'u.id=tu.user_id');
		$this->db->where('tu.tagged_user_id', $user_id);
		$this->db->order_by('tu.created_at', 'desc');
		$this->db->limit($limit, $offset);
		$query = $this->db->get();
		return $query->result();
	}
	
	public function search_user($keyword, $limit, $offset)
	{
		$this->db->select('*');
		$this->db->from('users');
		$this->db->where('active', 1);
		$this->db->like('first_name', $keyword, 'after');
		$this->db->limit($limit, $offset);
		$query = $this->db->get();
		return $query->result();
	}
	
	public function check_followed($user_from, $user_to)
	{
		$this->db->where('user_from', $user_from);
		$this->db->where('user_to', $user_to);
		$query = $this->db->get('friend_requests');
		if($query->num_rows() > 0) {
			return true;
		}
		else {
			return false;
		}
	}
	
	public function is_followed($user_id, $logged_user_id)
	{
		$this->db->where('user_from', $logged_user_id);
		$this->db->where('user_to', $user_id);
		$query = $this->db->get('friend_requests');
		if($query->num_rows() > 0) {
			return 'followed';
		}
		
		$this->db->where('user_from', $user_id);
		$this->db->where('user_to', $logged_user_id);
		$query = $this->db->get('friend_requests');
		if($query->num_rows() > 0) {
			return 'follower';
		}
		
		return false;
	}
	
	public function is_blocked($user_id, $logged_user_id)
	{
		$this->db->where('user_from', $logged_user_id);
		$this->db->where('user_to', $user_id);
		$query = $this->db->get('friend_requests');
		if($query->num_rows() > 0) {
			return $query->row();
		}
		
		$this->db->where('user_from', $user_id);
		$this->db->where('user_to', $logged_user_id);
		$query = $this->db->get('friend_requests');
		if($query->num_rows() > 0) {
			return $query->row();
		}
		
		return false;
	}
	
	public function count_like($video_id)
	{
		$this->db->where('video_id', $video_id);
		return $this->db->count_all_results('videos_likes');
	}
	
	public function is_liked($user_id, $video_id)
	{
		$this->db->where('user_id', $user_id);
		$this->db->where('video_id', $video_id);
		$query = $this->db->get('videos_likes');
		if($query->num_rows() > 0)
		{
			return TRUE;
		} 
		else {
			return FALSE;
		}
	}
	
	public function edit_frame($frame_id=null,$frame_data=null){
		$this->db->where('id',$frame_id);
		$this->db->update('ads_frame',$frame_data);
	}
	
	public function insert_direct_endorse($direct_endorse_data=null){
		$this->db->insert('direct_endorse', $direct_endorse_data);
		return $this->db->insert_id();
	}
	
	public function get_direct_endorse($from_user_id=null){
		$this->db->where('from_user_id',$from_user_id);
		$query = $this->db->get('direct_endorse');
		return $query->result();
	}
	
	
	/* Mahesh */
	function get_video_frames($video_id){
		$this->db->select('fr.*, v.kaltura_video_id, v.title as event_title, v.description as event_description');
		$this->db->from('ads_frame fr');
		$this->db->join('videos v', 'v.id = fr.video_id');
		$this->db->where('v.id', $video_id);
		$this->db->order_by('fr.start_time', 'ASC');
		$query = $this->db->get();
		return $query->result();
	}
	
	public function get_tagged_users_on_event($video_id) {
		$this->db->select('u.id,u.first_name,u.profile_image,tu.tagged_user_id');
		$this->db->from('tagged_users tu');
		$this->db->join('videos v', 'v.id=tu.video_id', 'left');
		$this->db->join('users u', 'u.id= tu.tagged_user_id');
		$this->db->where('tu.video_id', $video_id);
		$this->db->order_by('tu.created_at', 'desc');
		$query = $this->db->get();
		return $query->result();
	}
	
	function count_user_timeline($user_id){
		$this->db->where('tagged_user_id', $user_id); 
		$this->db->from('tagged_users');		
		return $this->db->count_all_results();
	}
	
	function count_video_timeline($video_id){
		$this->db->where('video_id', $user_id); 
		$this->db->from('tagged_users');		
		return $this->db->count_all_results();
	}
	function remove_session($user_id,$reg_id){
		$this->db->where('user_id',$user_id);
		$this->db->where('reg_token',$reg_id);
		$this->db->delete('user_session');
		
	}
	
	function remove_user($user_id=null){
		$this->db->delete('users', array('id' => $user_id));
        $this->db->delete('ads_frame', array('user_id' => $user_id));
        $this->db->delete('comments', array('user_id' => $user_id));
		$this->db->delete('direct_endorse', array('from_user_id' => $user_id));
		$this->db->delete('friends_list', array('user_id' => $user_id));
		$this->db->delete('friend_requests', array('user_from' => $user_id));
		$this->db->delete('message', array('user_from' => $user_id));
		$this->db->delete('notifications', array('from_user_id' => $user_id));
		$this->db->delete('products', array('user_id' => $user_id));
		$this->db->delete('product_orders', array('user_id' => $user_id));
		$this->db->delete('scheduled_video', array('user_id' => $user_id));
		$this->db->delete('subscribe_video', array('user_id' => $user_id));
		$this->db->delete('tagged_users', array('user_id' => $user_id));
		$this->db->delete('tag_streams', array('user_id' => $user_id));
		$this->db->delete('user_session', array('user_id' => $user_id));
		$this->db->delete('videos', array('user_id' => $user_id));
        $this->db->delete('videos_likes', array('user_id' => $user_id));

	}
	
	public function check_notification($frame_id)
	{
		$actionArray =array(2,3);
		//$this->db->where('from_user_id', $user_id);
		$this->db->where('event_id', $frame_id);
		$this->db->where_in('action_type', $actionArray);
		$query = $this->db->get('notifications');
		//echo $this->db->last_query();
		if($query->num_rows() > 0) {
			return true;
		}
		else {
			return false;
		}
		
	}
	public function remove_notification($frame_id){
		$actionArray =array(2,3);
		//$this->db->where('from_user_id', $user_id);
		$this->db->where('event_id', $frame_id);
		$this->db->where_in('action_type', $actionArray);
		$this->db->delete('notifications');
		
	}
	public function remove_frame($frame_id){
		//$this->db->where('user_id', $user_id);
		$this->db->where('id', $frame_id);
		$this->db->delete('ads_frame');
		
	}
	
	public function removeEventFrameNotification($frame_id){
		$actionArray =array(2,3);
		$this->db->where('event_id', $frame_id);
		$this->db->where_in('action_type', $actionArray);
		$this->db->delete('notifications');
		
	}
	public function removeEventNotification($event_id){
		$actionArray =array(1,10,6,7,8);
		$this->db->where('event_id', $event_id);
		$this->db->where_in('action_type', $actionArray);
		$this->db->delete('notifications');
		
	}
	public function removeEventFrame($frame_id){
		$this->db->where('id', $frame_id);
		$this->db->delete('ads_frame');
		
	}
	public function remove_event($event_id=null){
		//$this->db->where('user_id',$user_id);
        $this->db->where('id',$event_id);
		$this->db->delete('videos');
    }
	
	public function remove_video_likes($event_id=null){
		$this->db->where('video_id',$event_id);
		$this->db->delete('videos_likes');
    }
	public function remove_video_comments($event_id=null){
		$this->db->where('video_id',$event_id);
		$this->db->delete('comments');
    }
	public function remove_favourite_video($event_id=null){
		$this->db->where('video_id',$event_id);
		$this->db->delete('favourite_video');
    }
	public function tagged_users($event_id=null){
		$this->db->where('video_id',$event_id);
		$this->db->delete('tagged_users');
    }
	
	public function remove_tag_streams($event_id=null){
		$actionArray =array('add','edit','subscribe','comment');
		$this->db->where('event_id', $event_id);
		$this->db->where_in('action_type', $actionArray);
		$this->db->delete('tag_streams');
    }
	
	public function removeFrameTagStreams($frame_id){
		$actionArray =array('frame');
		$this->db->where('event_id', $frame_id);
		$this->db->where_in('action_type', $actionArray);
		$this->db->delete('tag_streams');
    }
		
				
	public function get_video_id($comment_id=null){
		$this->db->where('id',$comment_id);
		$query= $this->db->get('comments');
		return $query->row()->video_id;
	}
    public function get_event_userId($video_id=null){
        $this->db->where('id',$video_id);
		$query= $this->db->get('videos');
		return $query->row()->user_id;
    }	
    
	function checkFollowing($user_id,$user_to){
       $this->db->where('user_from',$user_id);
	   $this->db->where('user_to',$user_to);
	   $this->db->where('request',1);
	   $query= $this->db->get('friend_requests');
	   if($query->num_rows()>0){
		   return true;
	   }
	   else {
		   return false;
	   }
	   
	}
	
	/* function updateBlocked($user_from,$user_to,$data){
		$this->db->where('user_from',$user_from);
		$this->db->where('user_to',$user_to);
		$this->db->update('friend_requests',$data);
	} */
	
	/* public function updateBlocked($user_id, $logged_user_id,$data)
	{
		$this->db->where('user_from', $logged_user_id);
		$this->db->where('user_to', $user_id);
		$this->db->update('friend_requests',$data);
		if($this->db->affected_rows() > 0) {
			return true;
		}
		
		$this->db->where('user_to', $logged_user_id);
		$this->db->where('user_from', $user_id);
		$this->db->update('friend_requests',$data);
		if($this->db->affected_rows() > 0) {
			return true;
		}
		
		return false;
	} */	
	
	public function blocked_user_from($user_id, $logged_user_id,$data){
		
		$this->db->where('user_from', $logged_user_id);
		$this->db->where('user_to', $user_id);
		$this->db->update('friend_requests',$data);
		
    }
    public function blocked_user_to($user_id, $logged_user_id,$data){
		
		$this->db->where('user_from', $user_id);
		$this->db->where('user_to', $logged_user_id);
		$this->db->update('friend_requests',$data);
		
    }
	
	public function delete_user_from($user_id, $logged_user_id){
		
		$this->db->where('user_from', $logged_user_id);
		$this->db->where('user_to', $user_id);
		$this->db->delete('friend_requests');
		
    }
    public function delete_user_to($user_id, $logged_user_id){
		
		$this->db->where('user_from', $user_id);
		$this->db->where('user_to', $logged_user_id);
		$this->db->delete('friend_requests');
		
    }
	
	/* public function blocked_users($user_id){
		
		$SQL= "SELECT * FROM (`friend_requests`) WHERE (`user_from`=$user_id OR `user_to`= $user_id) AND `is_blocked`=1";
		$query = $this->db->query($SQL);
		
		if($query->num_rows()>0){
		   $result= $query->result();
		   $data=array();
		   foreach($result as $row){
			   
			   if($row->user_to==$user_id){
				   $data[]=$row->user_from;
			   }
			   if($row->user_from==$user_id){
				   $data[]=$row->user_to;
			   }
			   //echo "<pre>";print_r($row);
		   }
		   return $data;
	    }
	    else {
		   return false;
	    }
	} */
	
	public function blocked_users($user_id){
		
		$SQL= "SELECT * FROM (`friend_requests`) WHERE (`user_to`= $user_id) AND `is_blocked`=1";
		$query = $this->db->query($SQL);
		
		if($query->num_rows()>0){
		   $result= $query->result();
		   $data=array();
		    foreach($result as $row){
			    $data[]=$row->user_from;
			    /* if($row->user_to==$user_id){
				   $data[]=$row->user_from;
			    }
			    if($row->user_from==$user_id){
				   $data[]=$row->user_to;
			    } */
			    //echo "<pre>";print_r($row);
		   }
		   return $data;
	    }
	    else {
		   return false;
	    }
	}
	
	public function check_friend($user_id,$logged_user_id){
		
		$SQL= "SELECT * FROM (`friend_requests`) WHERE ((`user_from`=$logged_user_id AND `user_to`= $user_id) OR (`user_from`=$user_id AND `user_to`= $logged_user_id))";
		$query = $this->db->query($SQL);
		
		if($query->num_rows()>0){
		   return true;
	    }
	    else {
		   return false;
	    }
	}
	
	public function insert_friend($data){
		$this->db->insert('friend_requests',$data);
	}
	
}
