<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
class Frame extends MY_Controller {
    public $data;
	
	function __construct() {
		parent::__construct();
		if ( ! $this->ion_auth->logged_in()) {
			redirect('auth/login');
		}
		$this->load->library('kaltura/kaltura');
		$this->load->language('frame');
		$this->load->model('frame_model');
		$this->load->library('form_validation');
		$this->load->helper('text');
		$this->load->helper('media');
	}
	
	function index($video_id=null){
	
		$user_id = $this->ion_auth->get_user_id();
		
		$this->data['frames'] = $this->frame_model->get_video_frames($video_id);
		
		$this->template->load_view('frame/index', $this->data);
	}
	public function ajax_search_magento_product() {
		$keyword = $this->input->post('keyword', true);
	
		$this->load->library('bwt_magento');
		$products = $this->bwt_magento->product_search($keyword);
		$this->data['products'] = $products;
		
		$this->load->view('frame/product_search_result', $this->data);
	}
	
	public function ajax_magento_product_by_id() {
		$product_id = $this->input->post('product_id', true);
	
		$this->load->library('bwt_magento');
		$product = $this->bwt_magento->get_product($product_id);
		$this->data['product'] = $product;
		
		$this->load->view('frame/product_result', $this->data);
	}
	
	function create($video_id=NULL, $product_id=NULL){
	
		$this->template->set_title('Add Frame');
	
		$user_id = $this->ion_auth->get_user_id();
		
		$this->data['frame'] = 'frame';
		$this->data['error'] = "";
		//$this->template->set_layout('pagelet');
		
		$this->template->add_js('modules/frame.js');
		$this->template->add_js('moment-with-locales.js');
		
		$this->load->model('videos/videos_model');
		$this->data['videos'] = $this->videos_model->get_videos($user_id);
		
		$this->data['video_id'] = $video_id;
		$this->data['product_id'] = $product_id;
		
		if((int) $video_id) {
			$video = $this->videos_model->get_video('id', $video_id, $kaltura_user_id='');
			$friend_id = $video->user_id;
			
			$this->load->model('friends/friends_model');
			$check_friend = $this->friends_model->get_friend($user_id, $friend_id);
			
			if($video->type == 'public') {
				$this->data['permission'] = TRUE;
			} 
			else if( ! empty($check_friend)) {
				$this->data['permission'] = TRUE;
			} 
			else if($user_id == $video->user_id) {
				$this->data['permission'] = TRUE;
			} 
			else {
				$this->data['permission'] = FALSE;
				redirect(base_url());
			}
		} 
		else {
			$video_id = $this->input->post('video');
		}
		
		$media_type = $this->input->post('media_type');
		
		$this->load->library('upload');
		
		$uploadPath = 'media/temp/';
		$config['upload_path'] = $uploadPath;
		if($media_type == 'IMAGE') {
			$config['allowed_types'] = 'gif|jpg|jpeg|png';
		} 
		else {
			$config['allowed_types'] = 'mp4';
		}
		$config['encrypt_name'] = TRUE;
		$this->upload->initialize($config);
		
		$this->form_validation->set_rules('video', 'video', 'trim|required');
		$this->form_validation->set_rules('product_id', 'product', 'trim|required');
		$this->form_validation->set_error_delimiters('<div class="error">', '</div>');
		
		if($this->form_validation->run() == false) {
			$this->template->load_view('frame/add_frame', $this->data);
		}
		else if( ! $this->upload->do_upload('media_file')) {
			$this->data['error'] = $this->upload->display_errors();
			$this->template->load_view('frame/add_frame', $this->data);
		} 
		else {
		
			$upload_data = $this->upload->data();
			$mediafile = $upload_data['file_name'];
			
			$kaltura_user = $this->ion_auth->get_username();
			$media_file_path = $uploadPath.$mediafile;
			
			// Kaltura data
			$media = array(
				'user' => $kaltura_user,
				'access_type' => 'USER',
				'media_type' => $media_type,
				'title' => "Advertisement",
				'description' => NULL,
				'tags' => NULL,
				'media_path' => $media_file_path
			);
			$kmedia = $this->kaltura->uploadfile($media, $frame = TRUE);
			
			$video_duration = $this->input->post('video_duration');
			$compare_endtime = $this->input->post('compare_endtime');
			
			$frame_time = $this->frame_model->get_all_frames_bytime($video_id);
			
			if($this->input->post('end_time') == 0){ 
				if(count($frame_time) == 0){
					
					$start_time = 0;
					$end_time = $video_duration;
					
				} else {
					for($i=0; $i < count($frame_time); $i++){  
						
						if($frame_time[0]->start_time > 60){
							$start_time = 0;
							$end_time = $frame_time[0]->start_time;
						
						} elseif(($i+1) == count($frame_time)){ 
						
							$start_time = $frame_time[$i]->end_time;
							$end_time = ($compare_endtime <= 0) ? $video_duration : $this->input->post('end_time');
							
						} elseif(($frame_time[$i+1]->start_time - $frame_time[$i]->end_time > 60)) {
							
							$start_time = $frame_time[$i]->end_time;
							$end_time = $frame_time[$i+1]->start_time;
							break;
						}
					}
				}
			} else {
				$start_time = $this->input->post('start_time');
				$end_time = $this->input->post('end_time');
			}
			
			//Magento product
			$this->load->library('bwt_magento');
			$magento_product = $this->bwt_magento->get_product($this->input->post('product_id'));
			
			$frame_data = array(
				'video_id' => $video_id,
				'product_id' => $this->input->post('product_id'),
				'start_time' => $start_time,
				'end_time' => $end_time,
				'media_type' => $media_type,
				'frame_kaltura_media_id' => $kmedia->id,
				'frame_kaltura_user_id' => $kmedia->userId,
				'thumbnail_url' => $kmedia->thumbnailUrl,
				'product_url' => $magento_product->getProductUrl(),
				'created_on' => time()
			);
			
			$frame_id = $this->frame_model->insert('ads_frame', $frame_data);
			$video = $this->videos_model->get_video('id', $video_id, $kaltura_user_id=NULL);
			// Tag Streams
			$streams_data = array(
				'user_id' => $user_id,
				'stream_type' => 'event',
				'event_id' => $video_id,
				'action_type' => 'frame',
				'created_on' => time() 
			);
			$this->common_model->insert_tag_stream($streams_data);
			
			unlink($media_file_path);
			
			redirect('frame');
		}
	}
	
	function edit_frame($id){
	
		$this->template->set_title('Edit Frame');
	
		$user_id = $this->ion_auth->get_user_id();
		
		$this->data['frame'] = 'frame'; 
		//$this->template->set_layout('pagelet');
		
		$this->template->add_js('modules/frame.js');
		$this->template->add_js('moment-with-locales.js');
		
		$this->load->model('videos/videos_model');
		$this->data['videos'] = $this->videos_model->get_videos($user_id);
		
		//Get frame
		$frame = $this->frame_model->get_frame($id);
		$this->data['frame'] = $frame;
		
		//Magento product
		$this->load->library('bwt_magento');
		$magento_product = $this->bwt_magento->get_product($frame->product_id);
		$this->data['mage_product'] = $magento_product;
		
		$this->form_validation->set_rules('product_id', 'product', 'trim|required');
		$this->form_validation->set_error_delimiters('<div class="error">', '</div>');
		
		$update = true;
		$frame_kaltura_media_id = $frame->frame_kaltura_media_id;
		//$thumbnail_url = $frame->thumbnail_url;
	
		if($this->form_validation->run() == false) {
			$this->template->load_view('frame/edit_frame', $this->data);
		}
		else {
			
			$kaltura_user = $this->ion_auth->get_username();
			$media_type = $this->input->post('media_type');
			
			if( $_FILES && $_FILES['media_file']['name'] ) {
				
				$this->load->library('upload');
			
				$uploadPath = 'media/temp/';
				$config['upload_path'] = $uploadPath;
				if($media_type == 'IMAGE') {
					$config['allowed_types'] = 'gif|jpg|jpeg|png';
				} 
				else {
					$config['allowed_types'] = 'mp4';
				}
				$config['encrypt_name'] = TRUE;
				$this->upload->initialize($config);
				
				if( ! $this->upload->do_upload('media_file')) {
					$data['error'] = $this->upload->display_errors();
					$update = false;
					$this->template->load_view('frame/edit_frame', $this->data);
				} else {
				
					$upload_data = $this->upload->data();
					$mediafile = $upload_data['file_name'];
					$media_file_path = $uploadPath.$mediafile;
				}
			} 
			else {
				$media_file_path = FALSE;
			}
			
			if($update) {
				
				// Kaltura data
				$media = array(
					'user' => $kaltura_user,
					'access_type' => 'USER',
					'media_type' => $media_type,
					'title' => "Advertisement",
					'description' => NULL,
					'tags' => NULL,
					'media_path' => $media_file_path
				);
				
				$kmedia = $this->kaltura->update($frame_kaltura_media_id, $media, $frame = TRUE);
			
				$video_id = $this->input->post('video');
				$video_duration = $this->input->post('video_duration');
				$compare_endtime = $this->input->post('compare_endtime');
				
				$frame_time = $this->frame_model->get_all_frames_bytime($video_id);
				
				if($this->input->post('end_time') == 0){ 
					if(count($frame_time) == 0){
						
						$start_time = 0;
						$end_time = $video_duration;
						
					} else {
						for($i=0; $i < count($frame_time); $i++){  
							
							if($frame_time[0]->start_time > 0){
								$start_time = 0;
								$end_time = $frame_time[0]->start_time;
							
							} elseif(($i+1) == count($frame_time)){ 
							
								$start_time = $frame_time[$i]->end_time;
								$end_time = ($compare_endtime <= 0) ? $video_duration : $this->input->post('end_time');
								
							} elseif(($frame_time[$i+1]->start_time - $frame_time[$i]->end_time) > 60) {
								
								$start_time = $frame_time[$i]->end_time;
								$end_time = $frame_time[$i+1]->start_time;
								break;
							}
						}
					}
				} else {
					$start_time = $this->input->post('start_time');
					$end_time = $this->input->post('end_time');
				}
				
				//Magento product
				$this->load->library('bwt_magento');
				$magento_product = $this->bwt_magento->get_product($this->input->post('product_id'));
				
				$frame_data = array(
					'video_id' => $video_id,
					'product_id' => $this->input->post('product_id'),
					'start_time' => $start_time,
					'end_time' => $end_time,
					'media_type' => $media_type,
					'frame_kaltura_media_id' => $kmedia->id,
					'frame_kaltura_user_id' => $kmedia->userId,
					'thumbnail_url' => $kmedia->thumbnailUrl,
					'product_url' => $magento_product->getProductUrl(),
				);
				
				$where = array('id' => $id);
				$this->frame_model->update('ads_frame', $frame_data, $where);
				$this->session->set_flashdata('message', 'Frame update successfully');
				
				// Tag Streams
				$streams_data = array(
					'user_id' => $user_id,
					'stream_type' => 'event',
					'event_id' => $video_id,
					'action_type' => 'frame',
					'created_on' => time() 
				);
				$this->common_model->insert_tag_stream($streams_data);
				
				if($_FILES && $_FILES['video_file']['name']) { 
					unlink($video_file_path);
				}
				
				redirect('frame');
			}
		}
	}
	
	function frame_delete($id=null){
		
		// Delete media from kaltura
		$kaltura_user = $this->ion_auth->get_username();
		$frame = $this->frame_model->get_frame($id);
		$entryId = $frame->frame_kaltura_media_id;
		
		// Kaltura data
		$media = array(
			'user' => $kaltura_user,
			'access_type' => 'USER',
		);
		$this->kaltura->delete($media, $entryId);
		
		$this->frame_model->delete('ads_frame', array('id' => $id));
		
		$this->session->set_flashdata('message', 'Frame removed successfully.');
		redirect('frame');
	}
	
	function timeslot(){
		$video_id = $this->input->post('video_id');
		
		if( ! $video_id) {
			die;
		}
		
		//$video_id = 7;
		
		$this->load->model('videos/videos_model');
		$video = $this->videos_model->get_video('id', $video_id, $kaltura_user_id='', $active=1);
		$video_duration = $video->video_duration;
		
		$frames = $this->frame_model->get_video_frames($video_id);
		
		$timeslots = array();
		$k = 0;
		foreach($frames as $key => $frame) {
			$start_time = $frame->start_time;
			$end_time = $frame->end_time;
			
			if($key != 0) {
				$k = $key - 1;
				$nvsecond = ($start_time - $frames[$k]->end_time);
			} 
			else {
				$nvsecond = $start_time - 0;
			}
			
			$nvpercent = ($nvsecond * 100)/$video_duration;
			//$nvpercent = sprintf("%.2f",$nvpercent);
			$nvpercent = round($nvpercent);
			
			$blankslots = array(
				'color' => 'info',
				'length_second' => $nvsecond,
				'length_percent' => $nvpercent
			);
			
			$vsecond = ($end_time - $start_time);
			$vpercent = ($vsecond * 100)/$video_duration;
			//$vpercent = sprintf("%.2f",$vpercent);
			$vpercent = round($vpercent);
			
			$videolots = array(
				'color' => 'warning',
				'length_second' => $vsecond,
				'length_percent' => $vpercent
			);
			
			$timeslots[] = $blankslots;
			array_push($timeslots, $videolots);
			
			$totalVideoSecond += $vsecond;
			$totalBlankSecond += $nvsecond;
			
			$totalVideoPercent += $vpercent;
			$totalBlankPercent += $nvpercent;
		}
		
		$lnvsecond = ($video_duration - ($totalVideoSecond + $totalBlankSecond));
		
		$lnvpercent = (100 - ($totalVideoPercent + $totalBlankPercent));
		
		if($lnvsecond) {
			$lastBlankslots = array(
				'color' => 'info',
				'length_second' => $lnvsecond,
				'length_percent' => $lnvpercent
			);
			
			array_push($timeslots, $lastBlankslots);
		}
		
		$data['timeslots'] = $timeslots;
		
		$data['kaltura_video_id'] = $video->kaltura_video_id;
		$data['duration'] = $video_duration;
		
		$this->load->view('frame/player', $data);
		//$this->load->view('frame/timeslot', $data);
	}
	
	//End new updated code
	
	function ajax_check_start_time(){
		$video_id = $this->input->post('video_id');
		$start_time = $this->input->post('start_time');
		$end_time = $this->input->post('end_time');
		$id = $this->input->post('frame_id'); 
		/*  $video_id = 1;
		$start_time = '00:24:15';
		$end_time = '00:37:14';  */
		$values = $this->frame_model->get_startTime_status($id, $video_id, $start_time, $end_time);
		$i=0;
		foreach($values as $value){
			if($i != 0){
				echo ', ';
			} else {
				$i = 1;
			}
			echo (! $value->name) ? 'No product->(' : $value->name.'->(';
			echo $value->start_time.' - '.$value->end_time.')';
		}
	}
	
	function ajax_get_event_duration(){
		$video_id = $this->input->post('video_id');
		echo $this->frame_model->get_video_duration($video_id);
	}
   
   
    function frames($user_id){
		
		$this->data['user_id'] = $user_id;
		$this->data['user'] = $this->ion_auth->get_user($user_id);
		$this->data['total_followers'] = Modules::run('tagstream/followers');
		$this->data['total_following'] = Modules::run('tagstream/following');
		
		//$this->data['frames'] = $this->frame_model->get_video_frames($video_id=null);
		$limit = 10;
		$offset = 0;
		$this->data['frames'] = $this->ws_model->get_user_frames($user_id, $limit, $offset);
		
		$this->data['profileData'] = Modules::run("friends/get_profile",$user_id);
		
		$this->template->load_view('friends/profile/frames', $this->data);
	}
	
    public function user_frames($user_id) {
	
		$this->data['user_id'] = $user_id;
		$this->data['user'] = $this->ion_auth->get_user($user_id);
		$this->data['total_followers'] = Modules::run('tagstream/followers');
		$this->data['total_following'] = Modules::run('tagstream/following');
		
		$limit = 100;
		$offset = $next_records;
		 
		$frames = $this->ws_model->get_user_frames($user_id, $limit, $offset);
		
		$countframes = $this->ws_model->count_user_frames($user_id);
		
		$number_of_frames = COUNT($countframes);
		
		$framelist = array();
		 
		if( ! empty($frames)) {
		
			$kaltura_user = $this->ion_auth->get_username($user_id);
			
			foreach($frames as $vframe) {
						
				$frameDataUrl = "";
				if($vframe->media_type == 'VIDEO'){
					$frm_kaltura_video_id = $vframe->kaltura_video_id;
					$frmvideo = $this->kaltura->videolist($access_type='ADMIN', $kaltura_user='', $page='', $frm_kaltura_video_id, $catId = TRUE);
					$frameDataUrl = $frmvideo['result']->objects[0]->dataUrl;
					
					$frameDataUrl=$this->videoDataUrl($frm_kaltura_video_id);
				}
				if($vframe->media_type=="VIDEO"){
					$frame_media_type=111;
				}
				else if($vframe->media_type=="IMAGE"){
					$frame_media_type=110;
				}
				$magento_product = $this->bwt_magento->get_product($vframe->product_id);
			
				$framelist[] = array(
					'frame_id' => $vframe->id,
					'event_id' => $vframe->video_id,
					'user_id' => $vframe->user_id,
					'product_id' => $vframe->product_id,
					'product_image' => $magento_product->getImageUrl(),
					'frame_title' => $vframe->title,
					'frame_start_time' => $vframe->start_time,
					'frame_end_time' => $vframe->end_time,
					'frame_media_type' => $frame_media_type,
					'frame_kmedia_id' => $vframe->frame_kaltura_media_id,
					'frame_thumbnail_url' => $vframe->thumbnail_url,
					'frame_image_url' => $vframe->image_url,
					'frame_data_url' => $frameDataUrl,
					'frame_product_url' => $magento_product->getProductUrl(),
					'frame_resource_type' =>"internet",
				);
			}
		}
		$this->data['frames'] = $framelist;
		//echo "<pre>";print_r($frames );
		$this->data['profileData'] = Modules::run("friends/get_profile",$user_id);
		//$this->template->load_view('friends/profile/frames', $this->data);
		$this->template->load_view('friends/profile/user_frames', $this->data);
	}
	
	function videoDataUrl($kaltura_video_id){
		$dataUrl="http://14.tagframe.com/p/101/sp/10100/playManifest/entryId/".$kaltura_video_id."/flavorIds/0,2,3,4,5,6,7/format/applehttp/protocol/http/a.m3u8";
		return $dataUrl;
	}
	
	function videoThumbnailUrl($videoThumbnailUrl){
		$thumbnailUrl = $videoThumbnailUrl."/width/600/height/300";
		return $thumbnailUrl;
	}
}