<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Kaltura {

	var $ci;
	var $PARTNER_ID = '';
	var $ADMIN_SECRET = '';
	var $USER_SECRET = '';
	var $frameImageCategoryId = '';
	var $frameVideoCategoryId = '';
	var $videoCategoryId = '';
	
	public function __construct() {
		
		$this->ci =& get_instance();
		
		$this->ci->load->config('kaltura');
		
		require_once "KalturaClient.php";
		
		$this->PARTNER_ID = $this->ci->config->item('partner_id');
		$this->ADMIN_SECRET = $this->ci->config->item('admin_secret');
		$this->USER_SECRET = $this->ci->config->item('user_secret');
		
		
		$this->videoCategoryId = $this->ci->config->item('video_category_id');
		$this->frameImageCategoryId = $this->ci->config->item('frame_image_category_id');
		$this->frameVideoCategoryId = $this->ci->config->item('frame_video_category_id');
	}
	
	public function videolist($access_type, $user, $page=NULL, $id=NULL, $categoriesId = FALSE, $media_type=NULL) {
	
		$kconf = new KalturaConfiguration($this->PARTNER_ID);
		// If you want to use the API against your self-hosted CE,
		// go to your KMC and look at Settings -> Integration Settings to find your partner credentials
		// and add them above. Then insert the domain name of your CE below.
		// $kconf->serviceUrl = "http://www.mySelfHostedCEsite.com/";
		$kclient = new KalturaClient($kconf);
		if($access_type == 'ADMIN') {
			$ksession = $kclient->session->start($this->ADMIN_SECRET, $user, KalturaSessionType::ADMIN, $this->PARTNER_ID);
		} 
		else {
			$ksession = $kclient->session->start($this->ADMIN_SECRET, $user, KalturaSessionType::USER, $this->PARTNER_ID);
		}

		if (!isset($ksession)) {
			die("Could not establish Kaltura session. Please verify that you are using valid Kaltura partner credentials.");
		}

		$kclient->setKs($ksession);

		// Set the response format
		// KALTURA_SERVICE_FORMAT_JSON  json
		// KALTURA_SERVICE_FORMAT_XML   xml
		// KALTURA_SERVICE_FORMAT_PHP   php
		$kconf->format = KalturaClientBase::KALTURA_SERVICE_FORMAT_PHP;

		$kfilter = new KalturaMediaEntryFilter();
		
		if($categoriesId) {
			$kfilter->categoriesIdsMatchAnd = $this->videoCategoryId;
		} 
		else {
			$kfilter->categoriesIdsNotContains = $this->frameVideoCategoryId;
		}
		
		if($media_type == 'IMAGE') {
			$kfilter->mediaTypeEqual = KalturaMediaType::IMAGE;
		} 
		else {
			$kfilter->mediaTypeEqual = KalturaMediaType::VIDEO;
		}
		$kfilter->status = KalturaEntryStatus::READY;
		$kfilter->orderBy = KalturaMediaEntryOrderBy::CREATED_AT_DESC;
		
		if($id != NULL) {
			$kfilter->idEqual = $id;
		}
		
		// pager
		$pager = new KalturaFilterPager();
		$pager->pageSize = 8;
		$pager->pageIndex = ($page)? $page: 1;

		$result = $kclient->media->listAction($kfilter, $pager);
		
		$resultArray = array(
			'result' => $result,
			'pageSize' => $pager->pageSize,
			'pageIndex' => $pager->pageIndex
		);
		
		return $resultArray;
	}
	
	public function uploadfile($media=array(), $frame = FALSE) {
	
		$user = $media['user'];
		$access_type = $media['access_type'];
		$media_type = $media['media_type'];
		$title = $media['title'];
		$description = $media['description'];
		$tags = $media['tags'];
		$media_path = $media['media_path'];
		
		$kconf = new KalturaConfiguration($this->PARTNER_ID);
		// If you want to use the API against your self-hosted CE,
		// go to your KMC and look at Settings -> Integration Settings to find your partner credentials
		// and add them above. Then insert the domain name of your CE below.
		// $kconf->serviceUrl = "http://www.mySelfHostedCEsite.com/";
		$kclient = new KalturaClient($kconf);
		if($access_type == 'ADMIN') {
			$ksession = $kclient->session->start($this->ADMIN_SECRET, $user, KalturaSessionType::ADMIN, $this->PARTNER_ID);
		} 
		else {
			$ksession = $kclient->session->start($this->ADMIN_SECRET, $user, KalturaSessionType::USER, $this->PARTNER_ID);
		}

		if (!isset($ksession)) {
			die("Could not establish Kaltura session. Please verify that you are using valid Kaltura partner credentials.");
		}

		$kclient->setKs($ksession);

		// Set the response format
		// KALTURA_SERVICE_FORMAT_JSON  json
		// KALTURA_SERVICE_FORMAT_XML   xml
		// KALTURA_SERVICE_FORMAT_PHP   php
		$kconf->format = KalturaClientBase::KALTURA_SERVICE_FORMAT_PHP;

		//$movie = "piano.m4v";
		
		$entry = new KalturaMediaEntry();

		$entry->name = $title;
		$entry->description = $description;
		$entry->tags = $tags;
		
		if($media_type == 'VIDEO') {
			$entry->mediaType = KalturaMediaType::VIDEO;
			if($frame) {
				$entry->categoriesIds = $this->frameVideoCategoryId;
			} 
			else {
				$entry->categoriesIds = $this->videoCategoryId;
			}
		}
		if($media_type == 'IMAGE') {
			$entry->mediaType = KalturaMediaType::IMAGE;
			if($frame) {
				$entry->categoriesIds = $this->frameImageCategoryId;
			}
		}
		
		$token = $kclient->media->upload($media_path);
		$result = $kclient->media->addFromUploadedFile($entry, $token);

		/*echo '<h3>Media entry structure returned</h3>';
		echo '<pre>';
		print_r($result);
		echo '</pre>';
		*/
		return $result;
	}
	
	public function update($entryId, $media=array(), $frame = FALSE) {
	
		$user = $media['user'];
		$access_type = $media['access_type'];
		$media_type = $media['media_type'];
		$title = $media['title'];
		$description = $media['description'];
		$tags = $media['tags'];
		$media_path = $media['media_path'];
		
		$kconf = new KalturaConfiguration($this->PARTNER_ID);
		// If you want to use the API against your self-hosted CE,
		// go to your KMC and look at Settings -> Integration Settings to find your partner credentials
		// and add them above. Then insert the domain name of your CE below.
		// $kconf->serviceUrl = "http://www.mySelfHostedCEsite.com/";
		$kclient = new KalturaClient($kconf);
	
		if($access_type == 'ADMIN') {
			$ksession = $kclient->session->start($this->ADMIN_SECRET, $user, KalturaSessionType::ADMIN, $this->PARTNER_ID);
		} 
		else {
			$ksession = $kclient->session->start($this->ADMIN_SECRET, $user, KalturaSessionType::USER, $this->PARTNER_ID);
		}

		if (!isset($ksession)) {
			die("Could not establish Kaltura session. Please verify that you are using valid Kaltura partner credentials.");
		}

		$kclient->setKs($ksession);

		// Set the response format
		// KALTURA_SERVICE_FORMAT_JSON  json
		// KALTURA_SERVICE_FORMAT_XML   xml
		// KALTURA_SERVICE_FORMAT_PHP   php
		$kconf->format = KalturaClientBase::KALTURA_SERVICE_FORMAT_PHP;

		$entry = new KalturaMediaEntry();

		$entry->name = $title;
		$entry->description = $description;
		$entry->tags = $tags;
		
		if($media_type == 'VIDEO') {
			$entry->mediaType = KalturaMediaType::VIDEO;
			if($frame) {
				$entry->categoriesIds = $this->frameVideoCategoryId;
			}
			else {
				$entry->categoriesIds = $this->videoCategoryId;
			}
		}
		if($media_type == 'IMAGE') {
			$entry->mediaType = KalturaMediaType::IMAGE;
			if($frame) {
				$entry->categoriesIds = $this->frameImageCategoryId;
			}
		}
		
		if($media_path) {
			//delete old media
			$params = array(
				'user' => $user,
				'access_type' => $access_type
			);
			$this->delete($params, $entryId);
			
			$token = $kclient->media->upload($media_path);
			$result = $kclient->media->addFromUploadedFile($entry, $token);
		} 
		else {
			$result = $kclient->media->update($entryId, $entry);
		}

		return $result;
	}
	
	public function delete($media=array(), $entryId) {
	
		$user = $media['user'];
		$access_type = $media['access_type'];
		
		$kconf = new KalturaConfiguration($this->PARTNER_ID);
		// If you want to use the API against your self-hosted CE,
		// go to your KMC and look at Settings -> Integration Settings to find your partner credentials
		// and add them above. Then insert the domain name of your CE below.
		// $kconf->serviceUrl = "http://www.mySelfHostedCEsite.com/";
		$kclient = new KalturaClient($kconf);
		if($access_type == 'ADMIN') {
			$ksession = $kclient->session->start($this->ADMIN_SECRET, $user, KalturaSessionType::ADMIN, $this->PARTNER_ID);
		} 
		else {
			$ksession = $kclient->session->start($this->ADMIN_SECRET, $user, KalturaSessionType::USER, $this->PARTNER_ID);
		}

		if (!isset($ksession)) {
			die("Could not establish Kaltura session. Please verify that you are using valid Kaltura partner credentials.");
		}

		$kclient->setKs($ksession);

		// Set the response format
		// KALTURA_SERVICE_FORMAT_JSON  json
		// KALTURA_SERVICE_FORMAT_XML   xml
		// KALTURA_SERVICE_FORMAT_PHP   php
		$kconf->format = KalturaClientBase::KALTURA_SERVICE_FORMAT_PHP;
		
		$kclient->media->delete($entryId);
	}
	
	
	public function kvideo($kaltura_video_id, $kaltura_user=NULL, $media_type=NULL) {
	
		$videos = $this->videolist($access_type='ADMIN', $kaltura_user, $page='', $kaltura_video_id, $categoriesId = FALSE, $media_type);
		
		return $videos['result']->objects[0];
	}
	
}
