<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
class Friends_model extends CI_Model {
    function __construct() {
		parent::__construct();
	}
	
	function get_followers($user_id)
	{
		$this->db->select('u.*, f.user_from');
		$this->db->from('friend_requests f');
		$this->db->join('users u', 'u.id=f.user_from');
		$this->db->where('f.user_to', $user_id);
		$this->db->where('u.active', 1);
		$this->db->where('f.request', 1);
		$query = $this->db->get(); 
		return $query->result();
	}
	
	function get_following($user_id)
	{
		$this->db->select('u.*, f.user_to');
		$this->db->from('friend_requests f');
		$this->db->join('users u', 'u.id=f.user_to');
		$this->db->where('f.user_from', $user_id);
		$this->db->where('u.active', 1);
		$this->db->where('f.request', 1);
		$query = $this->db->get(); 
		return $query->result();
	}
	
	function get_recent_followers($user_id) {
		$this->db->select('u.*, f.user_from');
		$this->db->from('friend_requests f');
		$this->db->join('users u', 'u.id=f.user_from');
		$this->db->where('f.user_to', $user_id);
		$this->db->where('u.active', 1);
		$this->db->where('f.request', 1);
		$this->db->limit(10);
		$query = $this->db->get(); 
		return $query->result();
	}
	
	function count_followers($user_id) {
		$this->db->where('user_to', $user_id);
		$this->db->where('request',1);
		return $this->db->count_all_results('friend_requests');
	}
	
	function delete_followers($user_id, $user_from) {
		$this->db->where('user_to', $user_id);
		$this->db->where('user_from', $user_from);
		$this->db->delete('friend_requests');
	}
	
	function delete_following($user_id, $user_to) {
		$this->db->where('user_from', $user_id);
		$this->db->where('user_to', $user_to);
		$this->db->delete('friend_requests');
	}
	
	function get_search_users($user_id, $email_id){
		$this->db->select('id, first_name, last_name, email, profile_image');
		$this->db->where('email', $email_id);
		$this->db->where('id !=', $user_id);
		$this->db->where('active', 1);
		$query = $this->db->get('users'); 
		return $query->result();
	}
	
	function get_search_users_byusername($user_id, $username){
		$this->db->select('id, first_name, last_name, email, profile_image');
		$this->db->like('username', $username); 
		$this->db->where('id !=', $user_id);
		$this->db->where('active', 1);
		$query = $this->db->get('users'); 
		return $query->result();
	}
	
	function get_request_value($user_id, $search_id){
		$this->db->select('user_from, user_to, request');
		$this->db->where("( user_from='".$user_id."' and user_to='".$search_id."')");
		$this->db->or_where("( user_from='".$search_id."' and user_to='".$user_id."')");
		$query = $this->db->get('friend_requests'); 
		return $query->row();
	}
	
	function get_friend_lists($user_id, $search=null){
		$this->db->select('us.*, fl.friend_id');
		$this->db->from('friends_list fl');
		$this->db->join('users us', 'us.id=fl.friend_id');
		$this->db->where('fl.user_id', $user_id);
		$this->db->where('us.active', 1);
		if($search) {
			$this->db->like('username', $search, 'left');
		}
		$query = $this->db->get(); 
		return $query->result();
	}
	
	function get_friend_pending_lists($user_id){
		$this->db->select('fr.user_from, us.first_name, us.last_name, us.profile_image');
		$this->db->from('friend_requests fr');
		$this->db->join('users us', 'us.id=fr.user_from');
		$this->db->where('fr.user_to', $user_id);
		$this->db->where('fr.request', 0);
		$this->db->where('us.active', 1);
		$query = $this->db->get(); 
		return $query->result();
	}
	
	function get_friend_waiting_lists($user_id){
		$this->db->select('fr.user_to, us.first_name, us.last_name, us.profile_image');
		$this->db->from('friend_requests fr');
		$this->db->join('users us', 'us.id=fr.user_to');
		$this->db->where('fr.user_from', $user_id);
		$this->db->where('fr.request', 0);
		$this->db->where('us.active', 1);
		$query = $this->db->get(); 
		return $query->result();
	}
	
	function remove_friends_list($user_from, $user_to){
		$this->db->where("(user_id=".$user_from." and friend_id=".$user_to.") or (user_id=".$user_to." and friend_id=".$user_from.")");
		$this->db->delete('friends_list');
		return true;
	}
	
	function remove_friend_requests($user_from, $user_to){
		$this->db->where("(user_from=".$user_from." and user_to=".$user_to.") or (user_from=".$user_to." and user_to=".$user_from.")");
		$this->db->delete('friend_requests');
		return true;
	}
	
	function insert($table, $data){
		$this->db->insert($table, $data);
		return $this->db->insert_id();
	}
	
	function update($table, $data, $where){
		$this->db->where($where);
		$this->db->update($table, $data);
		return true;
	}
	
	function delete($table, $where){
		$this->db->where($where);
		$this->db->delete($table);
		return true;
	}
	
	public function get_friend($user_id, $friend_id) {
		$this->db->where('user_from', $user_id);
		$this->db->where('user_to', $friend_id);
		$this->db->where('request',1);
		$query = $this->db->get('friend_requests');
		return $query->row();
	}
	
	/* public function get_friend($user_id, $friend_id) {
		$this->db->where('user_id', $user_id);
		$this->db->where('friend_id', $friend_id);
		$query = $this->db->get('friends_list');
		return $query->row();
	} */
	
	function count_friends($user_id) {
		$this->db->where('user_id', $user_id);
		return $this->db->count_all_results('friends_list');
	}
	
	function get_recent_friends($user_id) {
		$this->db->select('us.*,frl.friend_id');
		$this->db->from('users us');
		$this->db->join('friends_list frl', 'us.id=frl.friend_id', 'right');
		$this->db->where('user_id', $user_id);
		$query = $this->db->get();
		return $query->result();
	}
	
	public function check_friend($user_from, $user_to) {
		$sql = "SELECT * FROM friend_requests WHERE (user_from='$user_from' AND user_to='$user_to') OR (user_from='$user_to' AND user_to='$user_from')";
		$query = $this->db->query($sql);
		if($query->num_rows() == 1) {
			return true;
		}
		else {
			return false;
		}
	}
	
	public function check_following($user_from, $user_to) {
		$sql = "SELECT * FROM friend_requests WHERE (user_from='$user_from' AND user_to='$user_to')";
		$query = $this->db->query($sql);
        
		if($query->num_rows() == 1) {
			return true;
		}
		else {
			return false;
		}
		
	}
	
	public function check_block($user_from,$user_to){
		$this->db->where('user_from',$user_from);
		$this->db->where('user_to',$user_to);
		$query= $this->db->get('friend_requests');
		
		
		if($query->num_rows() > 0) {
            $result= $query->row()->is_blocked;
			return $result;
		}
		else{
			return 0;
		}
	}
	
}