<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
class Videos extends MY_Controller {
    public $data;
	
	function __construct() {
		parent::__construct();
		$this->load->language('videos');
		$this->load->model('videos_model');
		$this->load->library('kaltura/kaltura');
		$this->load->library('form_validation');
		$this->load->helper('text');
		$this->load->helper('datetime');
		$this->load->helper('media');
		$this->load->library('common_lib');
	}
	
	public function index()
    {
        $this->template->set_title('Videos');
		$this->data['videos'] = "videos";
        $this->template->load_view('videos/listing', $this->data);
    }
	
	public function listing() {
		$this->data['videos'] = $this->kaltura->videolist($access_type='ADMIN', $kaltura_user='');
		$this->load->view('videos/listing', $this->data);
	}
	
	public function ajax_listing() {
		$page = $this->input->post('page');
		$this->data['videos'] = $this->kaltura->videolist($access_type='ADMIN', $kaltura_user='', $page);
		$this->load->view('videos/listing', $this->data);
	}
	
	public function player($kaltura_video_id) {
		$this->data['kaltura_video_id'] = $kaltura_video_id;
		
		//$this->template->add_css('lightbox.min.css');
		//$this->template->add_js('lightbox-plus-jquery.min.js');
		
		
		$this->data['user_id']= $user_id = $this->ion_auth->get_user_id();
		$video = $this->videos_model->get_video('kaltura_video_id', $kaltura_video_id, $kaltura_user_id='', $active=1);
		$this->data['video'] = $video;
	
		$video_id = "";
		if( ! empty( $video)) {
			$this->data['count_like'] = $this->videos_model->get_all_like_count($video->id);
			$this->data['check_like'] = $this->videos_model->check_video_like($user_id, $video->id);
			$video_id = $video->id;
		}
	
		$this->load->library('bwt_magento');
		$video_frames = $this->ws_model->get_video_frames($video_id);
		$frames = array();
		
		if( ! empty($video_frames)) {
			foreach($video_frames as $frame) {
		
				$frameDataUrl = "";
				if($frame->media_type == 'VIDEO'){
					$frm_kaltura_video_id = $frame->kaltura_video_id;
					$frmvideo = $this->kaltura->videolist($access_type='ADMIN', $kaltura_user='', $page='', $frm_kaltura_video_id, $catId = TRUE);
					
					$frameDataUrl=$this->videoDataUrl($frm_kaltura_video_id);
				}
		
				$magento_product = $this->bwt_magento->get_product($frame->product_id);
				if($frame->media_type=="VIDEO"){
					$frame_media_type=111;
				}
				else if($frame->media_type=="IMAGE"){
					$frame_media_type=110;
				}
				
				$ms= $frame->end_time-$frame->start_time;
				$s = intval($ms/1000);
				$frameTime = sprintf('%02d:%02d:%02d', ($s / 3600), ($s / 60 % 60), $s % 60);
				
				$frames[] = array(
					'frame_id' => $frame->id,
					'user_id' => $frame->user_id,
					'product_id' => $frame->product_id,
					'product_image' => $magento_product->getImageUrl(),
					'frame_title' => $frame->title,
					'frame_start_time' => $frame->start_time,
					'frame_end_time' => $frame->end_time,
					'frame_media_type' => $frame_media_type,
					'frame_kmedia_id' => $frame->frame_kaltura_media_id,
					'frame_thumbnail_url' => $frame->thumbnail_url,
					'frame_image_url' => $frame->image_url,
					'frame_data_url' => $frameDataUrl,
					'frame_product_url' => $magento_product->getProductUrl(),
					'frame_resource_type' =>"internet",
					'frame_time'=>$frameTime
				);
			}
		}
		
		//$this->load->helper('datetime');
		if($video->event_type=="VIDEO"){
					$event_media_type=111;
				}
		else if($video->event_type=="IMAGE"){
					$event_media_type=110;
		}
		/* Tagged users on a events*/
		$tagged_user_id=array();
		$this->load->model('events/event_model');
		$taggedUserData = $this->event_model->get_tagged_users_on_event($video_id);
		$num_of_comments= $this->videos_model->num_of_comments_video($video_id);
		
		$profile_pic= base_url().'media/default-user.png';
		if(!empty($taggedUserData)){
			
			foreach($taggedUserData as $taggedUser){
			if(!empty($taggedUser->profile_image)){
				$profile_pic=base_url().$taggedUser->profile_image;
			}
			$tagged_user_id[]=array(
			'tag_id'=>$taggedUser->tag_id,
			'name'=>$taggedUser->first_name,
			'user_id'=>$taggedUser->tagged_user_id,
			'profile_pic'=>$profile_pic,
			
			);
			}
			
		}
		$this->data['num_of_comments']= $this->videos_model->num_of_comments_video($video_id);
		
		$kvideoInfo = $this->kaltura->kvideo($kaltura_video_id);
		
		$this->load->config('kaltura');
		$this->data['partner_id']= $this->config->item('partner_id'); 
					
		$this->data['video_duration']= $kvideoInfo->msDuration;
		$this->data['frames'] = $frames;
		$this->data['video_id']=$video_id;
		$this->data['title']= $video->title;
		$this->data['description']= $video->description;
		$this->data['tagged_user_id']=$tagged_user_id;
		$this->data['event_user_id']=$video->user_id;
		
		$this->data['kvideo_id']=$kaltura_video_id;
		
		$this->load->view('videos/player_single', $this->data);
		//$this->load->view('videos/player', $this->data);
	}
	
	function frame_permission(){
		
		if ( ! $this->ion_auth->logged_in()) {
			echo 'not_logged_in';
		} 
		else {
			$user_id = $this->ion_auth->get_user_id();
			$video_id = $this->input->post('video_id');
			
			$video = $this->videos_model->get_video('id', $video_id, $kaltura_user_id='');
			$friend_id = $video->user_id;
			
			$this->load->model('friends/friends_model');
			$check_friend = $this->friends_model->get_friend($user_id, $friend_id);
			
			if($video->type == 'public') {
				echo 'true';
			} 
			else if(!empty($check_friend) /*&& $video->type =='friends'*/ ) {
				echo 'true';
			} 
			else if($user_id == $video->user_id) {
				echo 'true';
			} 
			else {
				echo 'false';
			}
		}
	}
	
	function like_video(){
		
		if ( ! $this->ion_auth->logged_in()) {
			echo 'not_logged_in';
		} 
		else {
			$user_id = $this->ion_auth->get_user_id();
			$video_id = $this->input->post('video_id');
			
			$data = array( 
				'user_id' => $user_id,
				'video_id' => $video_id,
				'created_on' => time()
			);
			
			$this->videos_model->insert('videos_likes', $data);
			
			$user= $this->common_model->get_user($video_id);
			if(!empty($user)){
				$from_user_id=$user_id;
				$to_user_id=$user->user_id;
				$action_type =8;
				$event_id =$video_id;
				
                if($from_user_id !=$to_user_id){
					$this->common_lib->notification($from_user_id,$to_user_id,$action_type,$event_id);
				}				
			}
			
			$count_like = $this->videos_model->get_all_like_count($video_id);
			echo $count_like;
		}
	}
	
	function unlike_video(){
		
		if ( ! $this->ion_auth->logged_in()) {
			echo 'not_logged_in';
		} 
		else {
			$user_id = $this->ion_auth->get_user_id();
			$video_id = $this->input->post('video_id');
			
			$this->videos_model->remove_video_like($user_id, $video_id);
			
			$count_like = $this->videos_model->get_all_like_count($video_id);
			echo $count_like;
		}
	}
	
	function create_favourite(){
	
		$user_id = $this->ion_auth->get_user_id();
		$video_id = $this->input->post('video_id');
	
		if ( ! $this->ion_auth->logged_in()) {
			echo 'not_logged_in';
		} 
		else if( ! $video_id) {
			redirect('/');
		} 
		else {
		
			$result = $this->videos_model->check_favourite($user_id, $video_id);	
			
			if($result){ 
				$response = "Already added in favourite.";
			} 
			else {
				$fav_data = array(
					'user_id'  => $user_id,
					'video_id' => $video_id,
					'created_on' => time()
				);
				
				$favourite_video_id = $this->videos_model->insert('favourite_video', $fav_data);	
				
				$video = $this->videos_model->get_video('id', $video_id, $kaltura_user_id='', $active=1);
				
				// Tag Streams
				$streams_data = array(
					'user_id' => $user_id,
					'stream_type' => 'event',
					'event_id' => $video_id,
					'action_type' => 'favourite',
					'created_on' => time() 
				);
				$this->common_model->insert_tag_stream($streams_data);
				
				$response = "Add favourite successfully.";
			}
			echo $response;
		}
	}
	
	function subscribe(){
	
		$user_id = $this->ion_auth->get_user_id();
		$video_id = $this->input->post('video_id');
	
		if ( ! $this->ion_auth->logged_in()) {
			echo 'not_logged_in';
		} 
		else if( ! $video_id) {
			redirect('/');
		} 
		else {
	
			$result = $this->videos_model->check_subscribe($user_id, $video_id);
			
			if($result){ 
				$response = "Already subscribed.";
			} 
			else {
				$subscribe_data = array(
					'user_id'  => $user_id,
					'video_id' => $video_id,
					'created_on' => time()
				);
				
				$subscribe_video_id = $this->videos_model->insert('subscribe_video', $subscribe_data);	
				
				$video = $this->videos_model->get_video('id', $video_id, $kaltura_user_id='', $active=1);
				
				// Tag Streams
				$streams_data = array(
					'user_id' => $user_id,
					'stream_type' => 'event',
					'event_id' => $video_id,
					'action_type' => 'subscribe',
					'created_on' => time() 
				);
				$this->common_model->insert_tag_stream($streams_data);
				
				$response = "Subscription successfully.";
			}
			echo $response;
		}
	}
	
	function user_videos(){
		if (!$this->ion_auth->logged_in()) {
			redirect('auth/login');
		}
		$this->template->set_title('Events');
		
		$user_id = $this->ion_auth->get_user_id();
		
		$kaltura_user = $this->ion_auth->get_username();
		$this->data['videos'] = $this->kaltura->videolist($access_type='USER', $kaltura_user, $page='', $id='', $categoriesId = TRUE);
		
		$this->template->load_view('videos/user_videos', $this->data);
	}
	
	function upload(){
		if (!$this->ion_auth->logged_in()) {
			redirect('auth/login');
		}
		
		$user_id = $this->ion_auth->get_user_id();
		
		$this->template->set_title('Create Event');
		$this->template->set_layout('pagelet');
		
		$this->template->add_js('modules/videos.js');
		
		$this->load->library('upload');
		
		$uploadPath = 'media/temp/';
		$config['upload_path'] = $uploadPath;
		$config['allowed_types'] = 'mp4|mov';
		$config['encrypt_name'] = TRUE;
		$this->upload->initialize($config);
		
		$this->form_validation->set_rules('title', 'title', 'trim|required');
		$this->form_validation->set_rules('description', 'description', 'trim|required');
		$this->form_validation->set_rules('tags_keywords', 'tags_keywords', 'trim|required');
		$this->form_validation->set_error_delimiters('<div class="error">', '</div>');
		
		if($this->form_validation->run() == false) {
			$this->template->load_view('videos/upload', $this->data);
		}
		else if( ! $this->upload->do_upload('video_file')) {
			$data['error'] = $this->upload->display_errors();
			$this->template->load_view('videos/upload', $this->data);
		} 
		else {
			$upload_data = $this->upload->data();
			$videofile = $upload_data['file_name'];
			
			$kaltura_user = $this->ion_auth->get_username();
			$video_file_path = $uploadPath.$videofile;
			
			// Kaltura data
			$media = array(
				'user' => $kaltura_user,
				'access_type' => 'USER',
				'media_type' => 'VIDEO',
				'title' => $this->input->post('title'),
				'description' => $this->input->post('description'),
				'tags' => $this->input->post('tags_keywords'),
				'media_path' => $video_file_path
			);
			
			$kvideo = $this->kaltura->uploadfile($media);
			
			$video_data =array(
				'user_id' => $user_id,
				'kaltura_user_id' => $kvideo->userId,
				'kaltura_video_id' => $kvideo->id,
				'type' => $this->input->post('type'),
				'title' => $this->input->post('title'),
				'description' => $this->input->post('description'),
				'tag_keyword' => $this->input->post('tags_keywords'),
				'price' => $this->input->post('price'),
				'is_paid' => $this->input->post('is_paid'),
				'created_on' =>  time()
			);
			
			$video_id = $this->videos_model->insert('videos', $video_data);
			
			// Tag Streams
			$streams_data = array(
				'user_id' => $user_id,
				'stream_type' => 'event',
				'event_id' => $video_id,
				'action_type' => 'add',
				'created_on' => time() 
			);
			$this->common_model->insert_tag_stream($streams_data);
			
			unlink($video_file_path);
			
			redirect('videos/user_videos');
		}
	}
	
	function edit_event($id){
		if (!$this->ion_auth->logged_in()) {
			redirect('auth/login');
		}
		if( ! $id) {
			redirect('videos/user_videos');
		}
		
		$user_id = $this->ion_auth->get_user_id();
		$kaltura_user = $this->ion_auth->get_username();
		
		$video = $this->videos_model->get_video('id', $id, $kaltura_user, $active=NULL);
		$this->data['video'] = $video;
		
		$this->template->set_title('Edit Event');
		$this->template->set_layout('pagelet');
		
		$this->template->add_js('modules/videos.js');
		
		$this->form_validation->set_rules('title', 'title', 'trim|required');
		$this->form_validation->set_rules('description', 'description', 'trim|required');
		$this->form_validation->set_rules('tags_keywords', 'tags_keywords', 'trim|required');
		$this->form_validation->set_error_delimiters('<div class="error">', '</div>');
		
		$update = true;
		$kaltura_video_id = $video->kaltura_video_id;
	
		if($this->form_validation->run() == false) {
			$this->template->load_view('videos/edit_event', $this->data);
		}
		else {
		
			$kaltura_user = $this->ion_auth->get_username();
			
			if($_FILES && $_FILES['video_file']['name']) {
		
				$this->load->library('upload');
			
				$uploadPath = 'media/temp/';
				$config['upload_path'] = $uploadPath;
				$config['allowed_types'] = 'mp4';
				$config['encrypt_name'] = TRUE;
				$this->upload->initialize($config);
				
				if( ! $this->upload->do_upload('video_file')) {
					$data['error'] = $this->upload->display_errors();
					$update = false;
					$this->template->load_view('videos/edit_event', $this->data);
				} 
				else {
				
					$upload_data = $this->upload->data();
					$videofile = $upload_data['file_name'];
					$video_file_path = $uploadPath.$videofile;
				}
			} 
			else {
				$video_file_path = FALSE;
			}
			
			if($update) {
				// Kaltura data
				$media = array(
					'user' => $kaltura_user,
					'access_type' => 'USER',
					'media_type' => 'VIDEO',
					'title' => $this->input->post('title'),
					'description' => $this->input->post('description'),
					'tags' => $this->input->post('tags_keywords'),
					'media_path' => $video_file_path
				);
				
				$kvideo = $this->kaltura->update($kaltura_video_id, $media);
				
				$video_data =array(
					'kaltura_video_id' => $kvideo->id,
					'video_duration' => $kvideo->duration,
					'type' => $this->input->post('type'),
					'title' => $this->input->post('title'),
					'description' => $this->input->post('description'),
					'tag_keyword' => $this->input->post('tags_keywords'),
					'price' => $this->input->post('price'),
					'is_paid' => $this->input->post('is_paid'),
				);
				
				$this->videos_model->update_event($user_id, $id, $video_data);
				
				// Tag Streams
				$streams_data = array(
					'user_id' => $user_id,
					'stream_type' => 'event',
					'event_id' => $id,
					'action_type' => 'edit',
					'created_on' => time() 
				);
				$this->common_model->insert_tag_stream($streams_data);
				
				if($_FILES && $_FILES['video_file']['name']) { 
					unlink($video_file_path);
				}
				
				redirect('videos/user_videos');
			}
		}
	}
	
	function duration($id, $kaltura_video_id) {
	
		$user_id = $this->ion_auth->get_user_id();
		$kaltura_user = $this->ion_auth->get_username();
		
		$kvideo = $this->kaltura->kvideo($kaltura_video_id, $kaltura_user);
		
		$video_data = array(
			'video_duration' => $kvideo->duration,
		);
		
		$this->videos_model->update_event($user_id, $id, $video_data);
		
		redirect('videos/user_videos');
	}
	
	function delete_event($id){
	
		if( ! $id) {
			redirect('videos/user_videos');
		}
	
		// Delete media from kaltura
		$kaltura_user = $this->ion_auth->get_username();
		$video = $this->videos_model->get_video('id', $id, $kaltura_user, $active=NULL);
		
		$kaltura_user = $this->ion_auth->get_username();
		
		// Kaltura data
		$media = array(
			'user' => $kaltura_user,
			'access_type' => 'USER',
		);
		$this->kaltura->delete($media, $video->kaltura_video_id);
		
		$user_id = $this->ion_auth->get_user_id();
		$this->videos_model->delete_event($user_id, $id);
		redirect('videos/user_videos');
	}
	
	function comment_view(){
		
		$user_id = $this->ion_auth->get_user_id();
		$video_id = $this->input->get_post('video_id');
		
		$this->data['video_id'] = $video_id;
		
		$comments = $this->videos_model->get_video_comments($video_id, $parent_id=0);
	    
		foreach($comments as $key => $value){
			
			$replyComment = $this->videos_model->get_video_comments($video_id, $value->id);
			
			$comments[$key]->replycomments = $replyComment;
		}
		
		$this->data['comments'] = $comments;
		//echo "<pre>";print_r($comments);die;
		$this->load->view('videos/ajax_comment', $this->data);
	}
	
	function add_comment(){
	
		if ( ! $this->ion_auth->logged_in()) {
			echo 'not_logged_in';
		}
		else {
	
			$user_id = $this->ion_auth->get_user_id();
			$video_id = $this->input->post('video_id');
			$comment = $this->input->post('comment');
			
			$comment_data = array(
				'user_id' => $user_id,
				'video_id' => $video_id,
				'comment' => $comment,
				'created_on' => $this->common_lib->currentTime($user_id),
				'status' => 1
			);
			$id = $this->videos_model->insert_comment($comment_data);
			
			// Tag Streams
			$streams_data = array(
				'user_id' => $user_id,
				'stream_type' => 'event',
				'event_id' => $video_id,
				'action_type' => 'comment',
				'created_on' => $this->common_lib->currentTime($user_id) 
			);
			$this->common_model->insert_tag_stream($streams_data);
			
			$comment = $this->videos_model->get_video_comment($id);
			
			if($comment->profile_image) {
					$profile_image = base_url().$comment->profile_image;
			} 
			else {
				$profile_image = base_url().'assets/img/no-image.png';
			}
			
			$respons = array(
				'id' => $comment->id,
				'parent_id' => $comment->parent_id,
				'video_id' => $comment->video_id,
				'profile_image' => $profile_image,
				'username' => $comment->username,
				'created_on' => date('F d, Y G:i A', $comment->created_on),
				'comment' => $comment->comment,
			);
			
			$user= $this->common_model->get_user($video_id);
				
		
			$this->output
				->set_content_type('application/json')
				->set_output(json_encode($respons));
			
            if(!empty($id)){
			   if(!empty($user)){
				$from_user_id=$user_id;
				$to_user_id=$user->user_id;
				$action_type =6;
				$event_id =$id.",".$video_id;
				
					if($from_user_id !=$to_user_id){
						$this->common_lib->notification($from_user_id,$to_user_id,$action_type,$event_id);		
					}
			    }	
		    } 
						
		}
	}
	
	function reply_comment(){
	
		if ( ! $this->ion_auth->logged_in()) {
			echo 'not_logged_in';
		}
		else {
	
			$user_id = $this->ion_auth->get_user_id();
			$parent_id = $this->input->post('comment_id');
			$video_id = $this->input->post('video_id');
			$comment = $this->input->post('comment');
			
			$comment_data = array(
				'parent_id' => $parent_id,
				'user_id' => $user_id,
				'video_id' => $video_id,
				'comment' => $comment,
				'created_on' => time(),
				'status' => 1
			);
			$id = $this->videos_model->insert_comment($comment_data);
			
			// Tag Streams
			$streams_data = array(
				'user_id' => $user_id,
				'stream_type' => 'event',
				'event_id' => $video_id,
				'action_type' => 'comment',
				'created_on' => time() 
			);
			$this->common_model->insert_tag_stream($streams_data);
			
			$comment = $this->videos_model->get_video_comment($id);
			
			if($comment->profile_image) {
					$profile_image = base_url().$comment->profile_image;
			} 
			else {
				$profile_image = base_url().'assets/img/no-image.png';
			}
			
			$respons = array(
				'id' => $comment->id,
				'parent_id' => $comment->parent_id,
				'video_id' => $comment->video_id,
				'profile_image' => $profile_image,
				'username' => $comment->username,
				'created_on' => date('F d, Y G:i A', $comment->created_on),
				'comment' => $comment->comment,
			);
			$user= $this->common_model->get_user($video_id);
			
			
			$this->output
				->set_content_type('application/json')
				->set_output(json_encode($respons));
			
			
			if(!empty($id)){
			   if(!empty($user)){
				$from_user_id=$user_id;
				$to_user_id=$user->user_id;
				$action_type =6;
				$event_id =$id.",".$video_id;
				
					if($from_user_id !=$to_user_id){
						$this->common_lib->notification($from_user_id,$to_user_id,$action_type,$event_id);		
					}
			    }	
		    } 	
		}
	}
	
	public function subscriptions() {
		if (!$this->ion_auth->logged_in()) {
			redirect('auth/login');
		}
		$this->template->set_title('Subscriptions');
		
		$user_id = $this->ion_auth->get_user_id();
		$this->data['videos'] = $this->videos_model->get_subscribed_videos($user_id);
		$this->template->load_view('videos/subscriptions', $this->data);
	}
	
	public function unsubscribe($video_id) {
		
		if (!$this->ion_auth->logged_in()) {
			redirect('auth/login');
		}
		
		$user_id = $this->ion_auth->get_user_id();
		$this->videos_model->unsubscribe($user_id, $video_id);
		
		redirect('videos/subscriptions');
	}
	
	public function favourites() {
		if (!$this->ion_auth->logged_in()) {
			redirect('auth/login');
		}
		$this->template->set_title('Favorites');
		
		$user_id = $this->ion_auth->get_user_id();
		$this->data['videos'] = $this->videos_model->get_favourite_videos($user_id);
		$this->template->load_view('videos/favourites', $this->data);
	}
	
	public function remove_favourite($video_id) {
		
		if (!$this->ion_auth->logged_in()) {
			redirect('auth/login');
		}
		
		$user_id = $this->ion_auth->get_user_id();
		$this->videos_model->delete_favourite($user_id, $video_id);
		
		redirect('videos/favourites');
	}
	
	
	function videoDataUrl($kaltura_video_id){
		$dataUrl="http://14.tagframe.com/p/101/sp/10100/playManifest/entryId/".$kaltura_video_id."/flavorIds/0,2,3,4,5,6,7/format/applehttp/protocol/http/a.m3u8";
		return $dataUrl;
	}
	
	function videoThumbnailUrl($videoThumbnailUrl){
		$thumbnailUrl = $videoThumbnailUrl."/width/600/height/300";
		return $thumbnailUrl;
	}
	
	
	// End new updated code
	
}